Hello and welcome,

this is an game platform on which you can play diffrent games.

To play those game you shoud import at first this 
libary and then call up the game which ypou want to play.

==========
 
"The game is imported"

from Skills_Game import < Game name >

"The game is started"

< Game name >.Start()

==========

Games:

[Pong]